package com.ruoyi.zhiyuanzhe.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zhiyuanzhe.domain.BActivityPoints;
import com.ruoyi.zhiyuanzhe.domain.request.BActivityPointsRequest;
import com.ruoyi.zhiyuanzhe.service.IBActivityPointsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * 一次性活动证书发放|积分获取Controller
 *
 * @author ruoyi
 * @date 2023-09-19
 */
@Api(tags = "一次性活动证书发放|积分获取")
@RestController
@RequestMapping("/zhiyuanzhe/points")
@Transactional(rollbackFor = Exception.class)
public class BActivityPointsController extends BaseController {
    @Autowired
    private IBActivityPointsService bActivityPointsService;

    /**
     * 分页查询一次性活动证书发放
     *
     * @param bActivityPoints 查询条件
     * @return 一次性活动证书发放
     */
    @ApiOperation(value = "分页查询一次性活动证书发放", response = BActivityPoints.class)
    @GetMapping("/list")
    public TableDataInfo list(BActivityPoints bActivityPoints) {
        startPage();
        List<BActivityPoints> list = bActivityPointsService.selectBActivityPointsList(bActivityPoints);
        return getDataTable(list);
    }

    /**
     * 导出一次性活动证书发放
     *
     * @param response        响应类
     * @param bActivityPoints 查询条件
     */
    @Log(title = "活动积分", businessType = BusinessType.EXPORT)
    @ApiOperation(value = "导出一次性活动证书发放")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BActivityPoints bActivityPoints) {
        List<BActivityPoints> list = bActivityPointsService.selectBActivityPointsList(bActivityPoints);
        ExcelUtil<BActivityPoints> util = new ExcelUtil<>(BActivityPoints.class);
        util.exportExcel(response, list, "活动积分数据");
    }

    /**
     * 获取一次性活动证书发放详细信息
     *
     * @param id 主键id
     * @return 一次性活动证书发放详细信息
     */
    @ApiOperation(value = "获取一次性活动证书发放详细信息", response = BActivityPoints.class)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bActivityPointsService.selectBActivityPointsById(id));
    }


    /**
     * 发放一次性证书
     *
     * @param req 发放一次性证书请求类
     * @return 响应类
     */
    @PostMapping("/issue")
    @ApiOperation(value = "发放一次性证书")
    public AjaxResult remove(@RequestBody @Valid BActivityPointsRequest req) {
        bActivityPointsService.issue(req);
        return success();
    }
}
