package com.ruoyi.zhiyuanzhe.controller;


import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zhiyuanzhe.domain.BCertificates;
import com.ruoyi.zhiyuanzhe.domain.request.BCertificatesRequest;
import com.ruoyi.zhiyuanzhe.domain.response.BCertificatesResponse;
import com.ruoyi.zhiyuanzhe.service.IBCertificatesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 个性化证书管理Controller
 *
 * @author ruoyi
 * @date 2023-09-19
 */
@RestController
@Api(tags = "个性化证书管理")
@RequestMapping("/zhiyuanzhe/certificates")
@Transactional(rollbackFor = Exception.class)
public class BCertificatesController extends BaseController {

    @Resource
    private IBCertificatesService bCertificatesService;

    /**
     * 查询个性化证书列表
     *
     * @param bCertificates 查询条件
     * @return 个性化证书列表
     */
    @ApiOperation(value = "查询个性化证书列表", response = BCertificates.class)
    @GetMapping("/list")
    public TableDataInfo list(BCertificates bCertificates) {
        startPage();
        List<BCertificates> list = bCertificatesService.selectBCertificatesList(bCertificates);
        return getDataTable(list);
    }

    /**
     * 根据分页条件查询个性化证书列表
     *
     * @param req 查询条件
     * @return 个性化证书列表
     */
    @ApiOperation(value = "根据分页条件查询个性化证书列表", response = BCertificatesResponse.class)
    @GetMapping("/sellectall")
    public AjaxResult selectAll(BCertificatesRequest req) {
        return AjaxResult.success(bCertificatesService.page(req));
    }


    /**
     * 导出个性化证书列表
     *
     * @param response      响应类
     * @param bCertificates 查询条件
     */
    @ApiOperation(value = "导出个性化证书列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BCertificates bCertificates) {
        List<BCertificates> list = bCertificatesService.selectBCertificatesList(bCertificates);
        ExcelUtil<BCertificates> util = new ExcelUtil<>(BCertificates.class);
        util.exportExcel(response, list, "个性化证书数据");
    }

    /**
     * 获取个性化证书详细信息
     *
     * @param id 个性化证书id
     * @return 个性化证书详细信息
     */
    @ApiOperation(value = "获取个性化证书详细信息", response = BCertificates.class)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bCertificatesService.selectBCertificatesById(id));
    }

    /**
     * 新增个性化证书
     *
     * @param bCertificates 个性化证书信息
     * @return 响应类
     */
    @ApiOperation(value = "新增个性化证书")
    @PostMapping
    public AjaxResult add(@RequestBody BCertificates bCertificates) {
        return toAjax(bCertificatesService.insertBCertificates(bCertificates));
    }

    /**
     * 修改个性化证书
     *
     * @param bCertificates 个性化证书信息
     * @return 响应类
     */
    @ApiOperation(value = "修改个性化证书")
    @PutMapping
    public AjaxResult edit(@RequestBody BCertificates bCertificates) {
        return toAjax(bCertificatesService.updateBCertificates(bCertificates));
    }

    /**
     * 删除个性化证书
     *
     * @param ids 个性化证书集合
     * @return 响应类
     */
    @ApiOperation(value = "删除个性化证书")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bCertificatesService.deleteBCertificatesByIds(ids));
    }
}
