package com.ruoyi.zhiyuanzhe.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.zhiyuanzhe.domain.BCertificates;
import com.ruoyi.zhiyuanzhe.domain.request.BCertificatesRequest;
import com.ruoyi.zhiyuanzhe.domain.request.PointsRedemptionExchangeRequest;
import com.ruoyi.zhiyuanzhe.service.PointsRedemptionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * 积分兑换消费
 *
 * @author wu
 * @since 2023/9/27 10:41
 */
@RestController
@Api(tags = "积分兑换消费")
@RequestMapping("/zhiyuanzhe/pointsRedemption")
@Transactional(rollbackFor = Exception.class)
public class PointsRedemptionController extends BaseController {

    @Resource
    private PointsRedemptionService pointsRedemptionService;

    /**
     * 查询可以兑换证书列表
     *
     * @param bCertificates 查询条件
     * @return 个性化证书列表
     */
    @ApiOperation(value = "查询可以兑换证书列表", response = BCertificates.class)
    @GetMapping("/page")
    public TableDataInfo list(BCertificatesRequest bCertificates) {
        startPage();
        List<BCertificates> list = pointsRedemptionService.page(bCertificates);
        return getDataTable(list);
    }


    /**
     * 查询用户所有积分
     *
     * @return 积分
     */
    @ApiOperation(value = "查询用户所有积分")
    @GetMapping("/findIntegral")
    public AjaxResult findIntegral() {
        Integer integral = pointsRedemptionService.findIntegral();
        return success(integral);
    }

    /**
     * 兑换证书
     *
     * @param req 兑换证书请求类
     * @return 响应类
     */
    @ApiOperation(value = "兑换证书")
    @PostMapping("/exchange")
    public AjaxResult exchange(@RequestBody @Valid PointsRedemptionExchangeRequest req) {
        pointsRedemptionService.exchange(req);
        return success();
    }

    /**
     * 查看证书详情
     *
     * @param id 证书id
     * @return 证书详情
     */
    @ApiOperation(value = "查看证书详情", response = BCertificates.class)
    @PostMapping("/findCertificatesById/{id}")
    public AjaxResult findCertificatesById(@PathVariable("id") Long id) {

        return success(pointsRedemptionService.findCertificatesById(id));
    }
}
